Adaa2

Struct Adaa2 

pub struct Adaa2 { /* private fields */ }
Second-order Antiderivative Anti-Aliasing processor.

Uses the second antiderivative for even better alias suppression, at the cost of one additional sample of latency and slight HF rolloff.

Implementations

Source

impl Adaa2

pub fn new(f: fn(f64) -> f64, ad1: fn(f64) -> f64, ad2: fn(f64) -> f64) -> Self

pub fn process(&mut self, x: f32) -> f32

Process one sample. Introduces 0.5 sample latency.

pub fn process_block(&mut self, buffer: &mut [f32])

pub fn reset(&mut self)