pub struct WindowedFrequencyResponse {
pub direct_sound_freq: Vec<f32>,
pub direct_sound_spl: Vec<f32>,
pub early_reflections_freq: Vec<f32>,
pub early_reflections_spl: Vec<f32>,
pub late_reverb_freq: Vec<f32>,
pub late_reverb_spl: Vec<f32>,
pub direct_end_ms: f64,
pub early_end_ms: f64,
}Expand description
Frequency responses computed from different time windows of an impulse response.
Direct sound, early reflections, and late reverb each have different perceptual roles (Toole, Johnston) and should be corrected differently.
Fields
direct_sound_freq: Vec<f32>Direct sound frequency response (frequencies in Hz, SPL in dB)
direct_sound_spl: Vec<f32>early_reflections_freq: Vec<f32>Early reflections frequency response
early_reflections_spl: Vec<f32>late_reverb_freq: Vec<f32>Late/reverberant field frequency response
late_reverb_spl: Vec<f32>direct_end_ms: f64Time boundaries used (in ms)
early_end_ms: f64Trait Implementations
Sourceimpl Clone for WindowedFrequencyResponse
impl Clone for WindowedFrequencyResponse
Sourcefn clone(&self) -> WindowedFrequencyResponse
fn clone(&self) -> WindowedFrequencyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for WindowedFrequencyResponse
impl RefUnwindSafe for WindowedFrequencyResponse
impl Send for WindowedFrequencyResponse
impl Sync for WindowedFrequencyResponse
impl Unpin for WindowedFrequencyResponse
impl UnsafeUnpin for WindowedFrequencyResponse
impl UnwindSafe for WindowedFrequencyResponse