Module auto_makeup
math_
audio_
dsp
0.5.13
Module auto_
makeup
Module Items
Structs
In crate math_
audio_
dsp
math_audio_dsp
Module
auto_
makeup
Structs

Measured
Makeup
Measured auto-makeup gain that tracks the actual average gain reduction and compensates for it, rather than using a fixed heuristic like
threshold × 0.5 × slope
.